@@ -376,6 +376,9 @@ mkinfit <- function(mkinmod, observed,
                                     fit$message)
       warning(fit$warning)
     }
+    else {
+      if(!quiet) cat("Optimisation by method", method.modFit, "successfully terminated.\n")
+    }
   }
   if (method.modFit %in% c("Port", "SANN", "Nelder-Mead", "BFGS", "CG", "L-BFGS-B")) {
     if (fit$convergence != 0) {
@@ -385,9 +388,17 @@ mkinfit <- function(mkinmod, observed,
                            ifelse(is.null(fit$message), "", 
                                   paste0("\nMessage is ", fit$message)))
       warning(fit$warning)
+    } else {
+      if(!quiet) cat("Optimisation by method", method.modFit, "successfully terminated.\n")
     }
   }
 
+  # Return number of iterations for SANN method
+  if (method.modFit == "SANN") {
+    fit$iter = maxit.modFit
+    if(!quiet) cat("Termination of the SANN algorithm does not imply convergence.\n")
+  }
+
   # We need to return some more data for summary and plotting
   fit$solution_type <- solution_type
   fit$transform_rates <- transform_rates
@@ -601,7 +612,7 @@ print.summary.mkinfit <- function(x, digits = max(3, getOption("digits") - 3), .
   cat("\nOptimised, transformed parameters:\n")
   print(signif(x$par, digits = digits))
 
-  if (x$niter != 0) {
+  if (x$calls > 0) {
     cat("\nParameter correlation:\n")
     if (!is.null(x$cov.unscaled)){
       Corr <- cov2cor(x$cov.unscaled)
